@@ -34,11 +34,14 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import annotations
+
+import os
 import warnings
 
 import numpy as np
 
-from phonopy.phonon.mesh import Mesh
+from phonopy.phonon.mesh import IterMesh, Mesh
 from phonopy.phonon.tetrahedron_mesh import TetrahedronMesh
 from phonopy.structure.tetrahedron_method import TetrahedronMethod
 
@@ -147,7 +150,9 @@ class Dos:
 class TotalDos(Dos):
     """Class to calculate total DOS."""
 
-    def __init__(self, mesh_object: Mesh, sigma=None, use_tetrahedron_method=False):
+    def __init__(
+        self, mesh_object: Mesh | IterMesh, sigma=None, use_tetrahedron_method=False
+    ):
         """Init method."""
         super().__init__(
             mesh_object,
@@ -155,7 +160,7 @@ class TotalDos(Dos):
             use_tetrahedron_method=use_tetrahedron_method,
         )
         self._dos = None
-        self._freq_Debye = None
+        self._freq_Debye: float | None = None
         self._Debye_fit_coef = None
         self._openmp_thm = True
 
@@ -197,7 +202,7 @@ class TotalDos(Dos):
         )
         return self._frequency_points, self._dos
 
-    def get_Debye_frequency(self):
+    def get_Debye_frequency(self) -> float | None:
         """Return a kind of Debye frequency."""
         return self._freq_Debye
 
@@ -253,7 +258,7 @@ class TotalDos(Dos):
             flip_xy=flip_xy,
         )
 
-    def write(self, filename="total_dos.dat"):
+    def write(self, filename: str | os.PathLike = "total_dos.dat"):
         """Write total DOS to total_dos.dat."""
         if self._tetrahedron_mesh is None:
             comment = "Sigma = %f" % self._sigma
