@@ -34,6 +34,9 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import annotations
+
+import os
 import warnings
 from typing import Optional, Union
 
@@ -603,7 +606,11 @@ class ThermalProperties(ThermalPropertiesBase):
                 np.array(cv, dtype="double"),
             )
 
-    def write_yaml(self, filename="thermal_properties.yaml", volume=None):
+    def write_yaml(
+        self,
+        filename: str | os.PathLike = "thermal_properties.yaml",
+        volume: float | None = None,
+    ):
         """Write thermal properties in yaml file."""
         lines = self._get_tp_yaml_lines(volume=volume)
         if self._is_projection:
@@ -654,7 +661,7 @@ class ThermalProperties(ThermalPropertiesBase):
             np.array(cv, dtype="double"),
         )
 
-    def _get_tp_yaml_lines(self, volume=None):
+    def _get_tp_yaml_lines(self, volume: float | None = None):
         lines = []
         lines.append("# Thermal properties / unit cell (natom)")
         lines.append("")
